import { BaseSearch } from "./BaseSearch.js";
import { EntryURLType, getEntryURLs } from "../tools/entry.js";
async function extractEntries(vault, memory) {
    // Get scores
    const scoresRaw = await memory.getValue(`bcup_search_${vault.id}`);
    let vaultScore = {};
    if (scoresRaw) {
        try {
            const scores = JSON.parse(scoresRaw);
            vaultScore = scores;
        }
        catch (err) { }
    }
    // Get entries
    return vault
        .getAllEntries()
        .filter((entry) => entry.isInTrash() === false)
        .map((entry) => {
        const properties = entry.getProperties();
        const urls = getEntryURLs(properties, EntryURLType.General);
        return {
            domainScores: vaultScore[entry.id] || {},
            entryType: entry.getType(),
            groupID: entry.getGroup().id,
            id: entry.id,
            properties,
            tags: entry.getTags(),
            urls,
            vaultID: vault.id
        };
    });
}
export class VaultEntrySearch extends BaseSearch {
    constructor(vaults, memory, searcherFactory) {
        super(vaults, extractEntries, memory, searcherFactory);
    }
}
